Class: SubskribeDevClient::AccountingPeriod

Inherits:
Object
  • Object
show all
Defined in:
lib/subskribe_dev/models/accounting_period.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AccountingPeriod

Initializes the object



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/subskribe_dev/models/accounting_period.rb', line 113

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'startDate')
    self.start_date = attributes[:'startDate']
  end

  if attributes.has_key?(:'endDate')
    self.end_date = attributes[:'endDate']
  end

  if attributes.has_key?(:'deferredRevenueBalance')
    self.deferred_revenue_balance = attributes[:'deferredRevenueBalance']
  end

  if attributes.has_key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.has_key?(:'syncStatus')
    self.sync_status = attributes[:'syncStatus']
  end

  if attributes.has_key?(:'openedBy')
    self.opened_by = attributes[:'openedBy']
  end

  if attributes.has_key?(:'openedOn')
    self.opened_on = attributes[:'openedOn']
  end

  if attributes.has_key?(:'closedBy')
    self.closed_by = attributes[:'closedBy']
  end

  if attributes.has_key?(:'closedOn')
    self.closed_on = attributes[:'closedOn']
  end

  if attributes.has_key?(:'calculation')
    self.calculation = attributes[:'calculation']
  end

  if attributes.has_key?(:'openedByUser')
    self.opened_by_user = attributes[:'openedByUser']
  end

  if attributes.has_key?(:'closedByUser')
    self.closed_by_user = attributes[:'closedByUser']
  end

  if attributes.has_key?(:'synthetic')
    self.synthetic = attributes[:'synthetic']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'entityId')
    self.entity_id = attributes[:'entityId']
  end
end

Instance Attribute Details

#calculationObject

Returns the value of attribute calculation.



35
36
37
# File 'lib/subskribe_dev/models/accounting_period.rb', line 35

def calculation
  @calculation
end

#closed_byObject

Returns the value of attribute closed_by.



31
32
33
# File 'lib/subskribe_dev/models/accounting_period.rb', line 31

def closed_by
  @closed_by
end

#closed_by_userObject

Returns the value of attribute closed_by_user.



39
40
41
# File 'lib/subskribe_dev/models/accounting_period.rb', line 39

def closed_by_user
  @closed_by_user
end

#closed_onObject

Returns the value of attribute closed_on.



33
34
35
# File 'lib/subskribe_dev/models/accounting_period.rb', line 33

def closed_on
  @closed_on
end

#deferred_revenue_balanceObject

Returns the value of attribute deferred_revenue_balance.



21
22
23
# File 'lib/subskribe_dev/models/accounting_period.rb', line 21

def deferred_revenue_balance
  @deferred_revenue_balance
end

#end_dateObject

Returns the value of attribute end_date.



19
20
21
# File 'lib/subskribe_dev/models/accounting_period.rb', line 19

def end_date
  @end_date
end

#entity_idObject

Returns the value of attribute entity_id.



45
46
47
# File 'lib/subskribe_dev/models/accounting_period.rb', line 45

def entity_id
  @entity_id
end

#idObject

Returns the value of attribute id.



43
44
45
# File 'lib/subskribe_dev/models/accounting_period.rb', line 43

def id
  @id
end

#opened_byObject

Returns the value of attribute opened_by.



27
28
29
# File 'lib/subskribe_dev/models/accounting_period.rb', line 27

def opened_by
  @opened_by
end

#opened_by_userObject

Returns the value of attribute opened_by_user.



37
38
39
# File 'lib/subskribe_dev/models/accounting_period.rb', line 37

def opened_by_user
  @opened_by_user
end

#opened_onObject

Returns the value of attribute opened_on.



29
30
31
# File 'lib/subskribe_dev/models/accounting_period.rb', line 29

def opened_on
  @opened_on
end

#start_dateObject

Returns the value of attribute start_date.



17
18
19
# File 'lib/subskribe_dev/models/accounting_period.rb', line 17

def start_date
  @start_date
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/subskribe_dev/models/accounting_period.rb', line 23

def status
  @status
end

#sync_statusObject

Returns the value of attribute sync_status.



25
26
27
# File 'lib/subskribe_dev/models/accounting_period.rb', line 25

def sync_status
  @sync_status
end

#syntheticObject

Returns the value of attribute synthetic.



41
42
43
# File 'lib/subskribe_dev/models/accounting_period.rb', line 41

def synthetic
  @synthetic
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/subskribe_dev/models/accounting_period.rb', line 70

def self.attribute_map
  {
    :'start_date' => :'startDate',
    :'end_date' => :'endDate',
    :'deferred_revenue_balance' => :'deferredRevenueBalance',
    :'status' => :'status',
    :'sync_status' => :'syncStatus',
    :'opened_by' => :'openedBy',
    :'opened_on' => :'openedOn',
    :'closed_by' => :'closedBy',
    :'closed_on' => :'closedOn',
    :'calculation' => :'calculation',
    :'opened_by_user' => :'openedByUser',
    :'closed_by_user' => :'closedByUser',
    :'synthetic' => :'synthetic',
    :'id' => :'id',
    :'entity_id' => :'entityId'
  }
end

.swagger_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/subskribe_dev/models/accounting_period.rb', line 91

def self.swagger_types
  {
    :'start_date' => :'Integer',
    :'end_date' => :'Integer',
    :'deferred_revenue_balance' => :'Float',
    :'status' => :'String',
    :'sync_status' => :'String',
    :'opened_by' => :'String',
    :'opened_on' => :'Integer',
    :'closed_by' => :'String',
    :'closed_on' => :'Integer',
    :'calculation' => :'AccountingPeriodCalculation',
    :'opened_by_user' => :'UserJson',
    :'closed_by_user' => :'UserJson',
    :'synthetic' => :'BOOLEAN',
    :'id' => :'String',
    :'entity_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/subskribe_dev/models/accounting_period.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      deferred_revenue_balance == o.deferred_revenue_balance &&
      status == o.status &&
      sync_status == o.sync_status &&
      opened_by == o.opened_by &&
      opened_on == o.opened_on &&
      closed_by == o.closed_by &&
      closed_on == o.closed_on &&
      calculation == o.calculation &&
      opened_by_user == o.opened_by_user &&
      closed_by_user == o.closed_by_user &&
      synthetic == o.synthetic &&
      id == o.id &&
      entity_id == o.entity_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/subskribe_dev/models/accounting_period.rb', line 275

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SubskribeDevClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/subskribe_dev/models/accounting_period.rb', line 341

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/subskribe_dev/models/accounting_period.rb', line 254

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


241
242
243
# File 'lib/subskribe_dev/models/accounting_period.rb', line 241

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



247
248
249
# File 'lib/subskribe_dev/models/accounting_period.rb', line 247

def hash
  [start_date, end_date, deferred_revenue_balance, status, sync_status, opened_by, opened_on, closed_by, closed_on, calculation, opened_by_user, closed_by_user, synthetic, id, entity_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



182
183
184
185
# File 'lib/subskribe_dev/models/accounting_period.rb', line 182

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



321
322
323
# File 'lib/subskribe_dev/models/accounting_period.rb', line 321

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



327
328
329
330
331
332
333
334
335
# File 'lib/subskribe_dev/models/accounting_period.rb', line 327

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



315
316
317
# File 'lib/subskribe_dev/models/accounting_period.rb', line 315

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



189
190
191
192
193
194
195
# File 'lib/subskribe_dev/models/accounting_period.rb', line 189

def valid?
  status_validator = EnumAttributeValidator.new('String', ['OPEN', 'CLOSE_IN_PROGRESS', 'CLOSED', 'UPCOMING'])
  return false unless status_validator.valid?(@status)
  sync_status_validator = EnumAttributeValidator.new('String', ['NONE', 'WAITING', 'IN_PROGRESS', 'SUCCEEDED', 'FAILED'])
  return false unless sync_status_validator.valid?(@sync_status)
  true
end