Class: SubskribeDevClient::OrderLineItemRequestJson

Inherits:
Object
  • Object
show all
Defined in:
lib/subskribe_dev/models/order_line_item_request_json.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OrderLineItemRequestJson

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 121

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'isDryRunItem')
    self.is_dry_run_item = attributes[:'isDryRunItem']
  end

  if attributes.has_key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.has_key?(:'planId')
    self.plan_id = attributes[:'planId']
  end

  if attributes.has_key?(:'subscriptionChargeId')
    self.subscription_charge_id = attributes[:'subscriptionChargeId']
  end

  if attributes.has_key?(:'chargeId')
    self.charge_id = attributes[:'chargeId']
  end

  if attributes.has_key?(:'quantity')
    self.quantity = attributes[:'quantity']
  end

  if attributes.has_key?(:'isRamp')
    self.is_ramp = attributes[:'isRamp']
  end

  if attributes.has_key?(:'discounts')
    if (value = attributes[:'discounts']).is_a?(Array)
      self.discounts = value
    end
  end

  if attributes.has_key?(:'predefinedDiscounts')
    if (value = attributes[:'predefinedDiscounts']).is_a?(Array)
      self.predefined_discounts = value
    end
  end

  if attributes.has_key?(:'effectiveDate')
    self.effective_date = attributes[:'effectiveDate']
  end

  if attributes.has_key?(:'endDate')
    self.end_date = attributes[:'endDate']
  end

  if attributes.has_key?(:'listUnitPrice')
    self.list_unit_price = attributes[:'listUnitPrice']
  end

  if attributes.has_key?(:'listPriceOverrideRatio')
    self.list_price_override_ratio = attributes[:'listPriceOverrideRatio']
  end

  if attributes.has_key?(:'attributeReferences')
    if (value = attributes[:'attributeReferences']).is_a?(Array)
      self.attribute_references = value
    end
  end

  if attributes.has_key?(:'customFields')
    if (value = attributes[:'customFields']).is_a?(Array)
      self.custom_fields = value
    end
  end

  if attributes.has_key?(:'dryRunItem')
    self.dry_run_item = attributes[:'dryRunItem']
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



21
22
23
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 21

def action
  @action
end

#attribute_referencesObject

Returns the value of attribute attribute_references.



45
46
47
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 45

def attribute_references
  @attribute_references
end

#charge_idObject

Returns the value of attribute charge_id.



27
28
29
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 27

def charge_id
  @charge_id
end

#custom_fieldsObject

Returns the value of attribute custom_fields.



47
48
49
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 47

def custom_fields
  @custom_fields
end

#discountsObject

Returns the value of attribute discounts.



33
34
35
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 33

def discounts
  @discounts
end

#dry_run_itemObject

Returns the value of attribute dry_run_item.



49
50
51
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 49

def dry_run_item
  @dry_run_item
end

#effective_dateObject

Returns the value of attribute effective_date.



37
38
39
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 37

def effective_date
  @effective_date
end

#end_dateObject

Returns the value of attribute end_date.



39
40
41
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 39

def end_date
  @end_date
end

#idObject

Returns the value of attribute id.



17
18
19
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 17

def id
  @id
end

#is_dry_run_itemObject

Returns the value of attribute is_dry_run_item.



19
20
21
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 19

def is_dry_run_item
  @is_dry_run_item
end

#is_rampObject

Returns the value of attribute is_ramp.



31
32
33
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 31

def is_ramp
  @is_ramp
end

#list_price_override_ratioObject

Returns the value of attribute list_price_override_ratio.



43
44
45
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 43

def list_price_override_ratio
  @list_price_override_ratio
end

#list_unit_priceObject

Returns the value of attribute list_unit_price.



41
42
43
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 41

def list_unit_price
  @list_unit_price
end

#plan_idObject

Returns the value of attribute plan_id.



23
24
25
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 23

def plan_id
  @plan_id
end

#predefined_discountsObject

Returns the value of attribute predefined_discounts.



35
36
37
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 35

def predefined_discounts
  @predefined_discounts
end

#quantityObject

Returns the value of attribute quantity.



29
30
31
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 29

def quantity
  @quantity
end

#subscription_charge_idObject

Returns the value of attribute subscription_charge_id.



25
26
27
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 25

def subscription_charge_id
  @subscription_charge_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 74

def self.attribute_map
  {
    :'id' => :'id',
    :'is_dry_run_item' => :'isDryRunItem',
    :'action' => :'action',
    :'plan_id' => :'planId',
    :'subscription_charge_id' => :'subscriptionChargeId',
    :'charge_id' => :'chargeId',
    :'quantity' => :'quantity',
    :'is_ramp' => :'isRamp',
    :'discounts' => :'discounts',
    :'predefined_discounts' => :'predefinedDiscounts',
    :'effective_date' => :'effectiveDate',
    :'end_date' => :'endDate',
    :'list_unit_price' => :'listUnitPrice',
    :'list_price_override_ratio' => :'listPriceOverrideRatio',
    :'attribute_references' => :'attributeReferences',
    :'custom_fields' => :'customFields',
    :'dry_run_item' => :'dryRunItem'
  }
end

.swagger_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 97

def self.swagger_types
  {
    :'id' => :'String',
    :'is_dry_run_item' => :'BOOLEAN',
    :'action' => :'String',
    :'plan_id' => :'String',
    :'subscription_charge_id' => :'String',
    :'charge_id' => :'String',
    :'quantity' => :'Integer',
    :'is_ramp' => :'BOOLEAN',
    :'discounts' => :'Array<DiscountJson>',
    :'predefined_discounts' => :'Array<String>',
    :'effective_date' => :'Integer',
    :'end_date' => :'Integer',
    :'list_unit_price' => :'Float',
    :'list_price_override_ratio' => :'Float',
    :'attribute_references' => :'Array<AttributeReference>',
    :'custom_fields' => :'Array<CustomFieldEntry>',
    :'dry_run_item' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 236

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      is_dry_run_item == o.is_dry_run_item &&
      action == o.action &&
      plan_id == o.plan_id &&
      subscription_charge_id == o.subscription_charge_id &&
      charge_id == o.charge_id &&
      quantity == o.quantity &&
      is_ramp == o.is_ramp &&
      discounts == o.discounts &&
      predefined_discounts == o.predefined_discounts &&
      effective_date == o.effective_date &&
      end_date == o.end_date &&
      list_unit_price == o.list_unit_price &&
      list_price_override_ratio == o.list_price_override_ratio &&
      attribute_references == o.attribute_references &&
      custom_fields == o.custom_fields &&
      dry_run_item == o.dry_run_item
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 294

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SubskribeDevClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 360

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 273

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 260

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



266
267
268
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 266

def hash
  [id, is_dry_run_item, action, plan_id, subscription_charge_id, charge_id, quantity, is_ramp, discounts, predefined_discounts, effective_date, end_date, list_unit_price, list_price_override_ratio, attribute_references, custom_fields, dry_run_item].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
211
212
213
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 206

def list_invalid_properties
  invalid_properties = Array.new
  if @charge_id.nil?
    invalid_properties.push('invalid value for "charge_id", charge_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 340

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
349
350
351
352
353
354
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 346

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



334
335
336
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 334

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



217
218
219
220
221
222
# File 'lib/subskribe_dev/models/order_line_item_request_json.rb', line 217

def valid?
  action_validator = EnumAttributeValidator.new('String', ['ADD', 'UPDATE', 'REMOVE', 'RENEWAL', 'NONE', 'MISSING_RENEWAL', 'RESTRUCTURE'])
  return false unless action_validator.valid?(@action)
  return false if @charge_id.nil?
  true
end