Class: SubskribeDevClient::SettingsApi
- Inherits:
-
Object
- Object
- SubskribeDevClient::SettingsApi
- Defined in:
- lib/subskribe_dev/api/settings_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#activate_unit_of_measure(id, opts = {}) ⇒ nil
Activate unit of measure Activates the specified unit of measure making it available to be attached to charges.
-
#activate_unit_of_measure_with_http_info(id, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Activate unit of measure Activates the specified unit of measure making it available to be attached to charges.
-
#add_unit_of_measure(opts = {}) ⇒ UnitOfMeasureJson
Add unit of measure Add a new instance of unit of measure as specified by the input.
-
#add_unit_of_measure_with_http_info(opts = {}) ⇒ Array<(UnitOfMeasureJson, Fixnum, Hash)>
Add unit of measure Add a new instance of unit of measure as specified by the input.
-
#delete_unit_of_measure(id, opts = {}) ⇒ UnitOfMeasureJson
Delete unit of measure Delete the unit of measure by Id provided.
-
#delete_unit_of_measure_with_http_info(id, opts = {}) ⇒ Array<(UnitOfMeasureJson, Fixnum, Hash)>
Delete unit of measure Delete the unit of measure by Id provided.
-
#deprecate_unit_of_measure(id, opts = {}) ⇒ nil
Deprecate unit of measure Deprecates the specified unit of measure making it unavailable to be attached to charges going forward.
-
#deprecate_unit_of_measure_with_http_info(id, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Deprecate unit of measure Deprecates the specified unit of measure making it unavailable to be attached to charges going forward.
-
#get_units_of_measure(opts = {}) ⇒ UnitOfMeasurePaginationResponseJson
Get units of measure Returns a paginated list of units of measure.
-
#get_units_of_measure_with_http_info(opts = {}) ⇒ Array<(UnitOfMeasurePaginationResponseJson, Fixnum, Hash)>
Get units of measure Returns a paginated list of units of measure.
-
#initialize(api_client = ApiClient.default) ⇒ SettingsApi
constructor
A new instance of SettingsApi.
-
#update_unit_of_measure(id, opts = {}) ⇒ UnitOfMeasureJson
Update unit of measure Update the unit of measure by Id provided.
-
#update_unit_of_measure_with_http_info(id, opts = {}) ⇒ Array<(UnitOfMeasureJson, Fixnum, Hash)>
Update unit of measure Update the unit of measure by Id provided.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SettingsApi
Returns a new instance of SettingsApi.
19 20 21 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#activate_unit_of_measure(id, opts = {}) ⇒ nil
Activate unit of measure Activates the specified unit of measure making it available to be attached to charges
27 28 29 30 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 27 def activate_unit_of_measure(id, opts = {}) activate_unit_of_measure_with_http_info(id, opts) nil end |
#activate_unit_of_measure_with_http_info(id, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Activate unit of measure Activates the specified unit of measure making it available to be attached to charges
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 37 def activate_unit_of_measure_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.activate_unit_of_measure ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettingsApi.activate_unit_of_measure" end # resource path local_var_path = '/unitsOfMeasure/{id}/activate'.sub('{' + 'id' + '}', id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['ApiKeyAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#activate_unit_of_measure\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#add_unit_of_measure(opts = {}) ⇒ UnitOfMeasureJson
Add unit of measure Add a new instance of unit of measure as specified by the input
78 79 80 81 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 78 def add_unit_of_measure(opts = {}) data, _status_code, _headers = add_unit_of_measure_with_http_info(opts) data end |
#add_unit_of_measure_with_http_info(opts = {}) ⇒ Array<(UnitOfMeasureJson, Fixnum, Hash)>
Add unit of measure Add a new instance of unit of measure as specified by the input
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 88 def add_unit_of_measure_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.add_unit_of_measure ...' end # resource path local_var_path = '/unitsOfMeasure' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['ApiKeyAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UnitOfMeasureJson') if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#add_unit_of_measure\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_unit_of_measure(id, opts = {}) ⇒ UnitOfMeasureJson
Delete unit of measure Delete the unit of measure by Id provided. Returns the deleted unit of measure object if successful.
128 129 130 131 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 128 def delete_unit_of_measure(id, opts = {}) data, _status_code, _headers = delete_unit_of_measure_with_http_info(id, opts) data end |
#delete_unit_of_measure_with_http_info(id, opts = {}) ⇒ Array<(UnitOfMeasureJson, Fixnum, Hash)>
Delete unit of measure Delete the unit of measure by Id provided. Returns the deleted unit of measure object if successful.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 138 def delete_unit_of_measure_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.delete_unit_of_measure ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettingsApi.delete_unit_of_measure" end # resource path local_var_path = '/unitsOfMeasure/{id}'.sub('{' + 'id' + '}', id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['ApiKeyAuth'] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UnitOfMeasureJson') if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#delete_unit_of_measure\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#deprecate_unit_of_measure(id, opts = {}) ⇒ nil
Deprecate unit of measure Deprecates the specified unit of measure making it unavailable to be attached to charges going forward
180 181 182 183 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 180 def deprecate_unit_of_measure(id, opts = {}) deprecate_unit_of_measure_with_http_info(id, opts) nil end |
#deprecate_unit_of_measure_with_http_info(id, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Deprecate unit of measure Deprecates the specified unit of measure making it unavailable to be attached to charges going forward
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 190 def deprecate_unit_of_measure_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.deprecate_unit_of_measure ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettingsApi.deprecate_unit_of_measure" end # resource path local_var_path = '/unitsOfMeasure/{id}/deprecate'.sub('{' + 'id' + '}', id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['ApiKeyAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#deprecate_unit_of_measure\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_units_of_measure(opts = {}) ⇒ UnitOfMeasurePaginationResponseJson
Get units of measure Returns a paginated list of units of measure
232 233 234 235 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 232 def get_units_of_measure(opts = {}) data, _status_code, _headers = get_units_of_measure_with_http_info(opts) data end |
#get_units_of_measure_with_http_info(opts = {}) ⇒ Array<(UnitOfMeasurePaginationResponseJson, Fixnum, Hash)>
Get units of measure Returns a paginated list of units of measure
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 243 def get_units_of_measure_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.get_units_of_measure ...' end # resource path local_var_path = '/unitsOfMeasure' # query parameters query_params = {} query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['ApiKeyAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UnitOfMeasurePaginationResponseJson') if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#get_units_of_measure\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_unit_of_measure(id, opts = {}) ⇒ UnitOfMeasureJson
Update unit of measure Update the unit of measure by Id provided.
284 285 286 287 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 284 def update_unit_of_measure(id, opts = {}) data, _status_code, _headers = update_unit_of_measure_with_http_info(id, opts) data end |
#update_unit_of_measure_with_http_info(id, opts = {}) ⇒ Array<(UnitOfMeasureJson, Fixnum, Hash)>
Update unit of measure Update the unit of measure by Id provided.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/subskribe_dev/api/settings_api.rb', line 295 def update_unit_of_measure_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.update_unit_of_measure ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettingsApi.update_unit_of_measure" end # resource path local_var_path = '/unitsOfMeasure/{id}'.sub('{' + 'id' + '}', id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['ApiKeyAuth'] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UnitOfMeasureJson') if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#update_unit_of_measure\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |